@@ -530,8 +530,10 @@ class accuinsight(object):
                     print('pass_message')
                     msg = message
                     response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
+                    print('response complete')
                 except SlackApiError as e:
                     assert e.response["error"]
+                    print('message_error')
         else:
             
             print('pass_else')
